| Home | Libraries | People | FAQ | More

## Index

A B C D E F H I M N O P R T U

A

  - add_const

  - add_cv

  - add_lvalue_reference

  - add_pointer

  - add_reference

  - add_rvalue_reference

  - add_volatile

  - aligned_storage

    - aligned_storage

    - align_t

  - alignment_of

    - alignment_of

    - align_t

    - integral_constant

  - align_t

    - aligned_storage

    - alignment_of

  - any

    - Operator Type Traits

B

  - Background and Tutorial

    - is_pointer

    - is_void

    - remove_extent

  - BOOST_ALIGNMENT_OF

    - Macros for Compiler Intrinsics

  - BOOST_BROKEN_COMPILER_TYPE_TRAITS_SPECIALIZATION

    - Type Traits that Transform One Type to Another

  - BOOST_COMMON_TYPE_DONT_USE_TYPEOF

    - common_type

  - BOOST_HAS_NOTHROW_ASSIGN

    - Macros for Compiler Intrinsics

  - BOOST_HAS_NOTHROW_CONSTRUCTOR

    - has_nothrow_constructor

    - Macros for Compiler Intrinsics

  - BOOST_HAS_NOTHROW_COPY

    - has_nothrow_copy

    - Macros for Compiler Intrinsics

  - BOOST_HAS_TRIVIAL_ASSIGN

    - has_trivial_assign

    - Macros for Compiler Intrinsics

  - BOOST_HAS_TRIVIAL_CONSTRUCTOR

    - has_trivial_constructor

    - Macros for Compiler Intrinsics

  - BOOST_HAS_TRIVIAL_COPY

    - has_trivial_copy

    - Macros for Compiler Intrinsics

  - BOOST_HAS_TRIVIAL_DESTRUCTOR

    - has_trivial_destructor

    - Macros for Compiler Intrinsics

  - BOOST_HAS_TRIVIAL_MOVE_ASSIGN

    - has_trivial_move_assign

    - Macros for Compiler Intrinsics

  - BOOST_HAS_TRIVIAL_MOVE_CONSTRUCTOR

    - has_trivial_move_constructor

    - Macros for Compiler Intrinsics

  - BOOST_HAS_VIRTUAL_DESTRUCTOR

    - has_virtual_destructor

    - Macros for Compiler Intrinsics

  - BOOST_IS_ABSTRACT

    - Macros for Compiler Intrinsics

  - BOOST_IS_BASE_OF

    - Macros for Compiler Intrinsics

  - BOOST_IS_CLASS

    - is_class

    - Macros for Compiler Intrinsics

  - BOOST_IS_CONVERTIBLE

    - Macros for Compiler Intrinsics

  - BOOST_IS_EMPTY

    - is_empty

    - Macros for Compiler Intrinsics

  - BOOST_IS_ENUM

    - Macros for Compiler Intrinsics

  - BOOST_IS_POD

    - is_pod

    - Macros for Compiler Intrinsics

  - BOOST_IS_POLYMORPHIC

    - Macros for Compiler Intrinsics

  - BOOST_IS_UNION

    - is_union

    - Macros for Compiler Intrinsics

C

  - common_type

    - BOOST_COMMON_TYPE_DONT_USE_TYPEOF

    - common_type

    - Improving std::min with common_type

D

  - decay

  - dont_care

    - has_bit_and

    - has_bit_and_assign

    - has_bit_or

    - has_bit_or_assign

    - has_bit_xor

    - has_bit_xor_assign

    - has_complement

    - has_dereference

    - has_divides

    - has_divides_assign

    - has_equal_to

    - has_greater

    - has_greater_equal

    - has_left_shift

    - has_left_shift_assign

    - has_less

    - has_less_equal

    - has_logical_and

    - has_logical_not

    - has_logical_or

    - has_minus

    - has_minus_assign

    - has_modulus

    - has_modulus_assign

    - has_multiplies

    - has_multiplies_assign

    - has_negate

    - has_not_equal_to

    - has_plus

    - has_plus_assign

    - has_post_decrement

    - has_post_increment

    - has_pre_decrement

    - has_pre_increment

    - has_right_shift

    - has_right_shift_assign

    - has_unary_minus

    - has_unary_plus

    - Operator Type Traits

E

  - extent

    - extent

    - integral_constant

F

  - false_type

    - integral_constant

  - floating_point_promotion

  - function_traits

    - function_traits

    - result_type

H

  - has_bit_and

    - dont_care

    - has_bit_and

    - trait

  - has_bit_and_assign

    - dont_care

    - has_bit_and_assign

    - trait

  - has_bit_or

    - dont_care

    - has_bit_or

    - trait

  - has_bit_or_assign

    - dont_care

    - has_bit_or_assign

    - trait

  - has_bit_xor

    - dont_care

    - has_bit_xor

    - trait

  - has_bit_xor_assign

    - dont_care

    - has_bit_xor_assign

    - trait

  - has_complement

    - dont_care

    - has_complement

    - trait

  - has_dereference

    - dont_care

    - has_dereference

    - trait

  - has_divides

    - dont_care

    - has_divides

    - trait

  - has_divides_assign

    - dont_care

    - has_divides_assign

    - trait

  - has_equal_to

    - dont_care

    - has_equal_to

    - Operator Type Traits

    - trait

  - has_greater

    - dont_care

    - has_greater

    - trait

  - has_greater_equal

    - dont_care

    - has_greater_equal

    - trait

  - has_left_shift

    - dont_care

    - has_left_shift

    - trait

  - has_left_shift_assign

    - dont_care

    - has_left_shift_assign

    - trait

  - has_less

    - dont_care

    - has_less

    - trait

  - has_less_equal

    - dont_care

    - has_less_equal

    - trait

  - has_logical_and

    - dont_care

    - has_logical_and

    - trait

  - has_logical_not

    - dont_care

    - has_logical_not

    - trait

  - has_logical_or

    - dont_care

    - has_logical_or

    - trait

  - has_minus

    - dont_care

    - has_minus

    - trait

  - has_minus_assign

    - dont_care

    - has_minus_assign

    - trait

  - has_modulus

    - dont_care

    - has_modulus

    - trait

  - has_modulus_assign

    - dont_care

    - has_modulus_assign

    - trait

  - has_multiplies

    - dont_care

    - has_multiplies

    - trait

  - has_multiplies_assign

    - dont_care

    - has_multiplies_assign

    - trait

  - has_negate

    - dont_care

    - has_negate

    - trait

  - has_new_operator

  - has_nothrow_assign

  - has_nothrow_constructor

    - BOOST_HAS_NOTHROW_CONSTRUCTOR

    - has_nothrow_constructor

    - has_nothrow_default_constructor

  - has_nothrow_copy

    - BOOST_HAS_NOTHROW_COPY

    - has_nothrow_copy

    - has_nothrow_copy_constructor

  - has_nothrow_copy_constructor

    - has_nothrow_copy

  - has_nothrow_default_constructor

    - has_nothrow_constructor

  - has_not_equal_to

    - dont_care

    - has_not_equal_to

    - trait

  - has_operator

    - Operator Type Traits

  - has_plus

    - dont_care

    - has_plus

    - trait

  - has_plus_assign

    - dont_care

    - has_plus_assign

    - trait

  - has_post_decrement

    - dont_care

    - has_post_decrement

    - trait

  - has_post_increment

    - dont_care

    - has_post_increment

    - trait

  - has_pre_decrement

    - dont_care

    - has_pre_decrement

    - trait

  - has_pre_increment

    - dont_care

    - has_pre_increment

    - trait

  - has_right_shift

    - dont_care

    - has_right_shift

    - trait

  - has_right_shift_assign

    - dont_care

    - has_right_shift_assign

    - trait

  - has_trivial_assign

    - BOOST_HAS_TRIVIAL_ASSIGN

    - has_trivial_assign

  - has_trivial_constructor

    - BOOST_HAS_TRIVIAL_CONSTRUCTOR

    - has_trivial_constructor

    - has_trivial_default_constructor

  - has_trivial_copy

    - BOOST_HAS_TRIVIAL_COPY

    - has_trivial_copy

    - has_trivial_copy_constructor

  - has_trivial_copy_constructor

    - has_trivial_copy

  - has_trivial_default_constructor

    - has_trivial_constructor

  - has_trivial_destructor

    - BOOST_HAS_TRIVIAL_DESTRUCTOR

    - has_trivial_destructor

  - has_trivial_move_assign

    - BOOST_HAS_TRIVIAL_MOVE_ASSIGN

    - has_trivial_move_assign

  - has_trivial_move_constructor

    - BOOST_HAS_TRIVIAL_MOVE_CONSTRUCTOR

    - has_trivial_move_constructor

  - has_unary_minus

    - dont_care

    - has_unary_minus

    - Operator Type Traits

    - trait

  - has_unary_plus

    - dont_care

    - has_unary_plus

    - trait

  - has_virtual_destructor

    - BOOST_HAS_VIRTUAL_DESTRUCTOR

    - has_virtual_destructor

I

  - Improving std::min with common_type

    - common_type

  - int

    - is_function

  - integral_constant

    - alignment_of

    - extent

    - false_type

    - integral_constant

    - Operator Type Traits

    - rank

    - true_type

  - integral_promotion

  - is_abstract

  - is_arithmetic

  - is_array

  - is_base_of

  - is_class

    - BOOST_IS_CLASS

    - is_class

    - User Defined Specializations

  - is_complex

  - is_compound

  - is_const

  - is_convertible

  - is_convertible_to_Ret

    - Operator Type Traits

  - is_copy_constructible

  - is_empty

    - BOOST_IS_EMPTY

    - is_empty

  - is_enum

  - is_floating_point

  - is_function

    - int

    - is_function

  - is_fundamental

  - is_integral

  - is_lvalue_reference

  - is_member_function_pointer

  - is_member_object_pointer

  - is_member_pointer

  - is_nothrow_move_assignable

  - is_nothrow_move_constructible

  - is_object

  - is_pod

    - BOOST_IS_POD

    - is_pod

    - User Defined Specializations

  - is_pointer

    - Background and Tutorial

    - is_pointer

  - is_polymorphic

  - is_reference

  - is_rvalue_reference

  - is_same

  - is_scalar

  - is_signed

  - is_stateless

  - is_union

    - BOOST_IS_UNION

    - is_union

    - User Defined Specializations

  - is_unsigned

  - is_virtual_base_of

  - is_void

    - Background and Tutorial

    - is_void

  - is_volatile

M

  - Macros for Compiler Intrinsics

    - BOOST_ALIGNMENT_OF

    - BOOST_HAS_NOTHROW_ASSIGN

    - BOOST_HAS_NOTHROW_CONSTRUCTOR

    - BOOST_HAS_NOTHROW_COPY

    - BOOST_HAS_TRIVIAL_ASSIGN

    - BOOST_HAS_TRIVIAL_CONSTRUCTOR

    - BOOST_HAS_TRIVIAL_COPY

    - BOOST_HAS_TRIVIAL_DESTRUCTOR

    - BOOST_HAS_TRIVIAL_MOVE_ASSIGN

    - BOOST_HAS_TRIVIAL_MOVE_CONSTRUCTOR

    - BOOST_HAS_VIRTUAL_DESTRUCTOR

    - BOOST_IS_ABSTRACT

    - BOOST_IS_BASE_OF

    - BOOST_IS_CLASS

    - BOOST_IS_CONVERTIBLE

    - BOOST_IS_EMPTY

    - BOOST_IS_ENUM

    - BOOST_IS_POD

    - BOOST_IS_POLYMORPHIC

    - BOOST_IS_UNION

  - make_signed

  - make_unsigned

N

  - no_operator

    - Operator Type Traits

O

  - Operator Type Traits

    - any

    - dont_care

    - has_equal_to

    - has_operator

    - has_unary_minus

    - integral_constant

    - is_convertible_to_Ret

    - no_operator

    - operator_exists

    - operator_returns_Ret

    - operator_returns_void

    - returns_void

    - returns_void_t

    - Rhs_nocv

    - Rhs_noptr

    - Rhs_noref

    - trait

    - trait_impl

    - trait_impl1

  - operator_exists

    - Operator Type Traits

  - operator_returns_Ret

    - Operator Type Traits

  - operator_returns_void

    - Operator Type Traits

P

  - promote

R

  - rank

    - integral_constant

    - rank

  - remove_all_extents

  - remove_const

  - remove_cv

  - remove_extent

    - Background and Tutorial

    - remove_extent

  - remove_pointer

  - remove_reference

  - remove_volatile

  - result_type

    - function_traits

  - returns_void

    - Operator Type Traits

  - returns_void_t

    - Operator Type Traits

  - Rhs_nocv

    - Operator Type Traits

  - Rhs_noptr

    - Operator Type Traits

  - Rhs_noref

    - Operator Type Traits

T

  - trait

    - has_bit_and

    - has_bit_and_assign

    - has_bit_or

    - has_bit_or_assign

    - has_bit_xor

    - has_bit_xor_assign

    - has_complement

    - has_dereference

    - has_divides

    - has_divides_assign

    - has_equal_to

    - has_greater

    - has_greater_equal

    - has_left_shift

    - has_left_shift_assign

    - has_less

    - has_less_equal

    - has_logical_and

    - has_logical_not

    - has_logical_or

    - has_minus

    - has_minus_assign

    - has_modulus

    - has_modulus_assign

    - has_multiplies

    - has_multiplies_assign

    - has_negate

    - has_not_equal_to

    - has_plus

    - has_plus_assign

    - has_post_decrement

    - has_post_increment

    - has_pre_decrement

    - has_pre_increment

    - has_right_shift

    - has_right_shift_assign

    - has_unary_minus

    - has_unary_plus

    - Operator Type Traits

  - trait_impl

    - Operator Type Traits

  - trait_impl1

    - Operator Type Traits

  - true_type

    - integral_constant

  - Type Traits that Transform One Type to Another

    - BOOST_BROKEN_COMPILER_TYPE_TRAITS_SPECIALIZATION

  - type_with_alignment

U

  - User Defined Specializations

    - is_class

    - is_pod

    - is_union